aboutsummaryrefslogtreecommitdiff
path: root/coreth.go
diff options
context:
space:
mode:
authorDeterminant <tederminant@gmail.com>2019-08-29 14:55:28 -0400
committerDeterminant <tederminant@gmail.com>2019-08-29 14:55:28 -0400
commit8c4e5b732d9584ecf9e77a4d93a987adb333d61a (patch)
treeea84ac4cb1ed8ca1bf08525d2739776473b1666d /coreth.go
parent1c1fa76addab68e04e051df3f38cce9f3bb32d98 (diff)
switch to ava-labs hosted geth
Diffstat (limited to 'coreth.go')
-rw-r--r--coreth.go16
1 files changed, 8 insertions, 8 deletions
diff --git a/coreth.go b/coreth.go
index a164452..a972175 100644
--- a/coreth.go
+++ b/coreth.go
@@ -8,12 +8,12 @@ import (
"github.com/ava-labs/coreth/consensus/dummy"
"github.com/ava-labs/coreth/eth"
"github.com/ava-labs/coreth/node"
- "github.com/ethereum/go-ethereum/common"
- "github.com/ethereum/go-ethereum/core/state"
- "github.com/ethereum/go-ethereum/core/types"
- "github.com/ethereum/go-ethereum/crypto"
- "github.com/ethereum/go-ethereum/event"
- "github.com/ethereum/go-ethereum/log"
+ "github.com/ava-labs/go-ethereum/common"
+ "github.com/ava-labs/go-ethereum/core/state"
+ "github.com/ava-labs/go-ethereum/core/types"
+ "github.com/ava-labs/go-ethereum/crypto"
+ "github.com/ava-labs/go-ethereum/event"
+ "github.com/ava-labs/go-ethereum/log"
"github.com/mattn/go-isatty"
)
@@ -100,9 +100,9 @@ func (self *ETHChain) GetBlockByHash(hash common.Hash) *types.Block {
return self.backend.BlockChain().GetBlockByHash(hash)
}
// SetHead sets the current head block to the one defined by the hash
// irrelevant what the chain contents were prior.
-func (self *ETHChain) SetHead(hash common.Hash) error {
+func (self *ETHChain) SetTail(hash common.Hash) error {
return self.backend.BlockChain().FastSyncCommitHead(hash)
}
@@ -100,9 +100,9 @@ func (self *ETHChain) GetBlockByHash(hash common.Hash) *types.Block {
return self.backend.BlockChain().GetBlockByHash(hash)
}
-// SetHead sets the current head block to the one defined by the hash
+// SetTail sets the current head block to the one defined by the hash
// irrelevant what the chain contents were prior.